@@ -17,11 +17,13 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.02';
+$VERSION = '0.022';
 
 use Doit::Log;
 use Doit::Util qw(in_directory);
 
+sub _pipe_open (@);
+
 sub new { bless {}, shift }
 sub functions { qw(git_repo_update git_short_status git_root git_get_commit_hash git_get_commit_files git_get_changed_files git_is_shallow git_current_branch git_config) }
 
@@ -33,6 +35,8 @@ sub git_repo_update {
     my $origin     = delete $opts{origin} || 'origin';
     my $allow_remote_url_change = delete $opts{allow_remote_url_change};
     my $clone_opts = delete $opts{clone_opts};
+    my $refresh    = delete $opts{refresh} || 'always';
+    if ($refresh !~ m{^(always|never)$}) { error "refresh may be 'always' or 'never'" }
     my $quiet      = delete $opts{quiet};
     error "Unhandled options: " . join(" ", %opts) if %opts;
 
@@ -68,19 +72,21 @@ sub git_repo_update {
 			"or specify allow_remote_url_change=>1\n";
 		}
 	    }
-	    if ($quiet) {
-		# XXX there's no quiet option for system, misuse qx instead
-		$self->qx({quiet=>1}, qw(git fetch));
-	    } else {
-		$self->system({show_cwd=>1}, qw(git fetch));
+	    if ($refresh eq 'always') {
+		if ($quiet) {
+		    # XXX there's no quiet option for system, misuse qx instead
+		    $self->qx({quiet=>1}, qw(git fetch));
+		} else {
+		    $self->system({show_cwd=>1}, qw(git fetch));
+		}
+		my $status = $self->git_short_status(untracked_files => 'no');
+		if ($status =~ m{>$}) {
+		    # may actually fail if diverged (status=<>)
+		    # or untracked/changed files would get overwritten
+		    $self->system({show_cwd=>1}, qw(git pull)); # XXX actually would be more efficient to do a merge or rebase, but need to figure out how git does it exactly...
+		    $has_changes = 1;
+		} # else: ahead, diverged, or something else
 	    }
-	    my $status = $self->git_short_status(untracked_files => 'no');
-	    if ($status =~ m{>$}) {
-		# may actually fail if diverged (status=<>)
-		# or untracked/changed files would get overwritten
-		$self->system({show_cwd=>1}, qw(git pull)); # XXX actually would be more efficient to do a merge or rebase, but need to figure out how git does it exactly...
-		$has_changes = 1;
-	    } # else: ahead, diverged, or something else
 	} $directory;
     } else {
 	my @cmd = (qw(git clone --origin), $origin);
@@ -111,7 +117,7 @@ sub git_short_status {
 	my $untracked_marker = '';
 	{
 	    my @cmd = ("git", "status", "--untracked-files=$untracked_files", "--porcelain");
-	    open my $fh, "-|", @cmd
+	    my $fh = _pipe_open(@cmd)
 		or error "Can't run '@cmd': $!";
 	    my $has_untracked;
 	    my $has_uncommitted;
@@ -140,7 +146,7 @@ sub git_short_status {
 
 	{
 	    my @cmd = ("git", "status", "--untracked-files=no");
-	    open my $fh, "-|", @cmd
+	    my $fh = _pipe_open(@cmd)
 		or error "Can't run '@cmd': $!";
 	    my $l;
 	    $l = <$fh>;
@@ -164,13 +170,13 @@ sub git_short_status {
 		    chomp(my $sha1_local = <$fh_local>);
 		    if ($sha1_remote ne $sha1_local) {
 			my $remote_is_newer;
-			if (open my $log_fh, '-|', 'git', 'log', '--pretty=format:%H', 'master..remotes/trunk') {
+			if (my $log_fh = _pipe_open('git', 'log', '--pretty=format:%H', 'master..remotes/trunk')) {
 			    if (scalar <$log_fh>) {
 				$remote_is_newer = 1;
 			    }
 			}
 			my $local_is_newer;
-			if (open my $log_fh, '-|', 'git', 'log', '--pretty=format:%H', 'remotes/trunk..master') {
+			if (my $log_fh = _pipe_open('git', 'log', '--pretty=format:%H', 'remotes/trunk..master')) {
 			    if (scalar <$log_fh>) {
 				$local_is_newer = 1;
 			    }
@@ -225,7 +231,7 @@ sub git_get_commit_files {
     my @files;
     in_directory {
 	my @cmd = ('git', 'show', $commit, '--pretty=format:', '--name-only');
-	open my $fh, '-|', @cmd
+	my $fh = _pipe_open(@cmd)
 	    or error "Error running @cmd: $!";
 	my $first = <$fh>;
 	if ($first ne "\n") { # first line is empty for older git versions (e.g. 1.7.x)
@@ -248,7 +254,7 @@ sub git_get_changed_files {
     my @files;
     in_directory {
 	my @cmd = qw(git status --porcelain);
-	open my $fh, '-|', @cmd
+	my $fh = _pipe_open(@cmd)
 	    or error "Error running @cmd: $!";
 	while(<$fh>) {
 	    chomp;
@@ -330,6 +336,19 @@ sub _is_dir_empty {
     return 1;
 }
 
+sub _pipe_open (@) {
+    my(@cmd) = @_;
+    my $fh;
+    if (Doit::IS_WIN && $] < 5.022) {
+	open $fh, '-|', Doit::Win32Util::win32_quote_list(@cmd)
+	    or return undef;
+    } else {
+	open $fh, '-|', @cmd
+	    or return undef;
+    }
+    return $fh;
+}
+
 1;
 
 __END__
